@@ -22,8 +22,6 @@
 #'           for t-distribution. The default (NULL) uses \code{\link[survey]{degf}},
 #'           but Inf is the usual survey package's default (except in
 #'           \code{\link[survey]{svyciprop}}.
-#' @param .svy A \code{tbl_svy} object. When called from inside a summarize function
-#'   the default automatically sets the survey to the current survey.
 #' @param ... Ignored
 #' @examples
 #' library(survey)
@@ -33,7 +31,7 @@
 #'   as_survey_design(strata = stype, weights = pw)
 #'
 #' dstrata %>%
-#'   summarise(api99 = survey_mean(api99),
+#'   summarise(api99_mn = survey_mean(api99),
 #'             api_diff = survey_mean(api00 - api99, vartype = c("ci", "cv")))
 #'
 #' dstrata %>%
@@ -66,25 +64,26 @@
 #'
 #' @export
 survey_mean <- function(
-  x, na.rm = FALSE, vartype = c("se", "ci", "var", "cv"), level = 0.95,
-  proportion = FALSE, prop_method = c("logit", "likelihood", "asin", "beta", "mean"),
-  deff = FALSE, df = NULL, .svy = current_svy(), ...
+  x,
+  na.rm = FALSE,
+  vartype = c("se", "ci", "var", "cv"),
+  level = 0.95,
+  proportion = FALSE,
+  prop_method = c("logit", "likelihood", "asin", "beta", "mean"),
+  deff = FALSE,
+  df = NULL,
+  ...
 ) {
-  UseMethod("survey_mean", .svy)
-}
+  .svy <- cur_svy()
 
-#' @export
-survey_mean.tbl_svy <- function(
-  x, na.rm = FALSE, vartype = c("se", "ci", "var", "cv"), level = 0.95,
-  proportion = FALSE, prop_method = c("logit", "likelihood", "asin", "beta", "mean"),
-  deff = FALSE, df = NULL, .svy = current_svy(), ...
-) {
   if (!is.null(vartype)) {
     vartype <- if (missing(vartype)) "se" else match.arg(vartype, several.ok = TRUE)
   }
   prop_method <- match.arg(prop_method)
-  if (is.null(df)) df <- survey::degf(.svy)
-  if (missing(x)) stop("Variable should be provided as an argument to survey_mean() or grouped survey object should be used.")
+  if (is.null(df)) df <- survey::degf(cur_svy_full())
+  if (missing(x)) return(survey_prop(vartype = vartype, level = level,
+                                     proportion = proportion, prop_method = prop_method,
+                                     deff = deff, df = df, .svy = cur_svy()))
   stop_for_factor(x)
   if (!proportion) {
     if (is.logical(x)) x <- as.integer(x)
@@ -104,49 +103,44 @@ survey_mean.tbl_svy <- function(
   }
 }
 
+#' @rdname survey_mean
 #' @export
-survey_mean.grouped_svy <- function(
-  x, na.rm = FALSE, vartype = c("se", "ci", "var", "cv"), level = 0.95,
-  proportion = FALSE, prop_method = c("logit", "likelihood", "asin", "beta", "mean"),
-  deff = FALSE, df = NULL, .svy = current_svy(), ...
+survey_prop <- function(
+  vartype = c("se", "ci", "var", "cv"),
+  level = 0.95,
+  proportion = FALSE,
+  prop_method = c("logit", "likelihood", "asin", "beta", "mean"),
+  deff = FALSE,
+  df = NULL,
+  ...
 ) {
+  .svy <- cur_svy()
+  .full_svy <- cur_svy_full()
+
   if (!is.null(vartype)) {
     vartype <- if (missing(vartype)) "se" else match.arg(vartype, several.ok = TRUE)
   }
-  if (is.null(df)) df <- survey::degf(.svy)
+  prop_method <- match.arg(prop_method)
+  if (is.null(df)) df <- survey::degf(.full_svy)
 
-  if (missing(prop_method)) prop_method <- "logit"
-  prop_method <- match.arg(prop_method, several.ok = TRUE)
+  if (!proportion) {
+    # TODO: This could be faster if we actually use survey::svyby()
+    x <- peeled_cur_group_id(.full_svy, cur_group())
+    .full_svy <- set_survey_vars(.full_svy, x)
 
-  if (missing(x) & proportion) {
-    stop("proportion does not work with factors.")
-  } else if (missing(x)) {
-    survey_stat_factor(.svy, survey::svymean, na.rm, vartype, level, deff, df)
+    stat <- survey::svymean(~`__SRVYR_TEMP_VAR__`, .full_svy, na.rm = TRUE, deff = deff)
+    out <- get_var_est(stat, vartype, level = level, df = df, deff = deff)
+    out
   } else {
-    stop_for_factor(x)
-    if (is.logical(x)) x <- as.integer(x)
-    .svy <- set_survey_vars(.svy, x)
-    grps_formula <- survey::make.formula(group_vars(.svy))
+    if (!isFALSE(deff)) warning("Cannot calculate design effects on proportions.", call. = FALSE)
+    # (Not possible to use svyby here, so I think this is as fast as it can be)
+    x <- peeled_cur_group_id(.full_svy, cur_group())
+    .full_svy <- set_survey_vars(.full_svy, x)
 
-    if (proportion) {
-      if (!isFALSE(deff)) {
-        warning("Cannot calculate design effects on proportions.", call. = FALSE)
-        deff <- FALSE
-      }
-      stat <- survey::svyby(
-        ~`__SRVYR_TEMP_VAR__`, grps_formula, .svy, survey::svyciprop, na.rm = na.rm,
-        se = TRUE, vartype = c("se", "ci"), method = prop_method, level = level
-      )
-    } else {
-      stat <- survey::svyby(
-        ~`__SRVYR_TEMP_VAR__`, grps_formula, .svy, survey::svymean,
-        deff = deff, na.rm = na.rm
-      )
-    }
-    out <- get_var_est(
-      stat, vartype, grps = group_vars(.svy), level = level, df = df,
-      pre_calc_ci = proportion, deff = deff
+    stat <- survey::svyciprop(
+      ~`__SRVYR_TEMP_VAR__`, .full_svy, na.rm = TRUE, level = level, method = prop_method
     )
+    out <- get_var_est(stat, vartype, pre_calc_ci = TRUE, df = df)
     out
   }
 }
@@ -167,8 +161,6 @@ survey_mean.grouped_svy <- function(
 #' @param df (For vartype = "ci" only) A numeric value indicating the degrees of freedom
 #'           for t-distribution. The default (NULL) uses \code{\link[survey]{degf}},
 #'           but Inf is the usual survey package's default.
-#' @param .svy A \code{tbl_svy} object. When called from inside a summarize function
-#'   the default automatically sets the survey to the current survey.
 #' @param ... Ignored
 #' @examples
 #' library(survey)
@@ -178,7 +170,7 @@ survey_mean.grouped_svy <- function(
 #'   as_survey_design(strata = stype, weights = pw)
 #'
 #' dstrata %>%
-#'   summarise(enroll = survey_total(enroll),
+#'   summarise(enroll_tot = survey_total(enroll),
 #'             tot_meals = survey_total(enroll * meals / 100, vartype = c("ci", "cv")))
 #'
 #' dstrata %>%
@@ -207,24 +199,25 @@ survey_mean.grouped_svy <- function(
 #'
 #' @export
 survey_total <- function(
-  x, na.rm = FALSE, vartype = c("se", "ci", "var", "cv"), level = 0.95,
-  deff = FALSE, df = NULL, .svy = current_svy(), ...
+  x,
+  na.rm = FALSE,
+  vartype = c("se", "ci", "var", "cv"),
+  level = 0.95,
+  deff = FALSE,
+  df = NULL,
+  ...
 ) {
-  UseMethod("survey_total", .svy)
-}
+  .svy <- cur_svy()
 
-#' @export
-survey_total.tbl_svy <- function(
-  x, na.rm = FALSE, vartype = c("se", "ci", "var", "cv"), level = 0.95,
-  deff = FALSE, df = NULL, .svy = current_svy(), ...
-) {
   if (!is.null(vartype)) {
     vartype <- if (missing(vartype)) "se" else match.arg(vartype, several.ok = TRUE)
   }
 
-  if (is.null(df)) df <- survey::degf(.svy)
+  if (is.null(df)) df <- survey::degf(cur_svy_full())
 
-  if (missing(x)) stop("Variable should be provided as an argument to survey_total() or grouped survey object should be used.")
+  if (missing(x)) {
+    x <- rep(1L, nrow(.svy))
+  }
   stop_for_factor(x)
   if (is.logical(x)) x <- as.integer(x)
 
@@ -235,35 +228,6 @@ survey_total.tbl_svy <- function(
   out
 }
 
-#' @export
-survey_total.grouped_svy <- function(
-  x, na.rm = FALSE, vartype = c("se", "ci", "var", "cv"), level = 0.95,
-  deff = FALSE, df = NULL, .svy = current_svy(), ...
-) {
-  if (!is.null(vartype)) {
-    vartype <- if (missing(vartype)) "se" else match.arg(vartype, several.ok = TRUE)
-  }
-  if (is.null(df)) df <- survey::degf(.svy)
-
-  if (missing(x)) {
-    survey_stat_factor(.svy, survey::svytotal, na.rm, vartype, level, deff, df)
-  } else {
-    stop_for_factor(x)
-    if (is.logical(x)) x <- as.integer(x)
-    .svy <- set_survey_vars(.svy, x)
-    grps_formula <- survey::make.formula(group_vars(.svy))
-
-    stat <- survey::svyby(
-      ~`__SRVYR_TEMP_VAR__`, grps_formula, .svy, survey::svytotal,
-      deff = deff, na.rm = na.rm
-    )
-    out <- get_var_est(
-      stat, vartype, grps = group_vars(.svy), level = level, df = df, deff = deff
-    )
-    out
-  }
-}
-
 #' Calculate the ratio and its variation using survey methods
 #'
 #' Calculate ratios from complex survey data. A wrapper
@@ -282,8 +246,6 @@ survey_total.grouped_svy <- function(
 #'           for t-distribution. The default (NULL) uses \code{\link[survey]{degf}},
 #'           but Inf is the usual survey package's default (except in
 #'           \code{\link[survey]{svyciprop}}.
-#' @param .svy A \code{tbl_svy} object. When called from inside a summarize function
-#'   the default automatically sets the survey to the current survey.
 #' @param ... Ignored
 #' @examples
 #' library(survey)
@@ -316,21 +278,21 @@ survey_total.grouped_svy <- function(
 #'
 #' @export
 survey_ratio <- function(
-  numerator, denominator, na.rm = FALSE, vartype = c("se", "ci", "var", "cv"),
-  level = 0.95, deff = FALSE, df = NULL, .svy  = current_svy(), ...
+  numerator,
+  denominator,
+  na.rm = FALSE,
+  vartype = c("se", "ci", "var", "cv"),
+  level = 0.95,
+  deff = FALSE,
+  df = NULL,
+  ...
 ) {
-  UseMethod("survey_ratio", .svy)
-}
+  .svy <- cur_svy()
 
-#' @export
-survey_ratio.tbl_svy <- function(
-  numerator, denominator, na.rm = FALSE, vartype = c("se", "ci", "var", "cv"),
-  level = 0.95, deff = FALSE, df = NULL, .svy = current_svy(), ...
-) {
   if (!is.null(vartype)) {
     vartype <- if (missing(vartype)) "se" else match.arg(vartype, several.ok = TRUE)
   }
-  if (is.null(df)) df <- survey::degf(.svy)
+  if (is.null(df)) df <- survey::degf(cur_svy_full())
   stop_for_factor(numerator)
   stop_for_factor(denominator)
 
@@ -346,33 +308,6 @@ survey_ratio.tbl_svy <- function(
   out
 }
 
-#' @export
-survey_ratio.grouped_svy <- function(
-  numerator, denominator, na.rm = FALSE, vartype = c("se", "ci", "var", "cv"),
-  level = 0.95, deff = FALSE, df = NULL, .svy = current_svy(), ...
-) {
-  if (!is.null(vartype)) {
-    vartype <- if (missing(vartype)) "se" else match.arg(vartype, several.ok = TRUE)
-  }
-  if (is.null(df)) df <- survey::degf(.svy)
-  stop_for_factor(numerator)
-  stop_for_factor(denominator)
-
-  grp_names <- group_vars(.svy)
-
-  .svy <- set_survey_vars(.svy, numerator, "__SRVYR_TEMP_NUM__")
-  .svy <- set_survey_vars(.svy, denominator, "__SRVYR_TEMP_DEN__", add = TRUE)
-
-  stat <- survey::svyby(
-    ~`__SRVYR_TEMP_NUM__`, survey::make.formula(grp_names), .svy,
-    survey::svyratio, denominator = ~`__SRVYR_TEMP_DEN__`,
-    na.rm = na.rm, ci = TRUE, deff = deff
-  )
-
-  out <- get_var_est(stat, vartype, grps = grp_names, level = level, df = df, deff = deff)
-  out
-}
-
 #' Calculate the quantile and its variation using survey methods
 #'
 #' Calculate quantiles from complex survey data. A wrapper
@@ -393,8 +328,6 @@ survey_ratio.grouped_svy <- function(
 #' @param df A number indicating the degrees of freedom for t-distribution. The
 #'           default, Inf uses the normal distribution (matches the survey package).
 #'           Also, has no effect for \code{type = "betaWald"}.
-#' @param .svy A \code{tbl_svy} object. When called from inside a summarize function
-#'   the default automatically sets the survey to the current survey.
 #' @param ... Ignored
 #' @examples
 #' library(survey)
@@ -413,21 +346,20 @@ survey_ratio.grouped_svy <- function(
 #'
 #' @export
 survey_quantile <- function(
-  x, quantiles, na.rm = FALSE, vartype = NULL,
-  level = 0.95, q_method = "linear", f = 1,
+  x,
+  quantiles,
+  na.rm = FALSE,
+  vartype = c("se", "ci", "var", "cv"),
+  level = 0.95,
+  q_method = "linear",
+  f = 1,
   interval_type = c("Wald", "score", "betaWald", "probability", "quantile"),
-  ties = c("discrete", "rounded"), df = NULL, .svy = current_svy(), ...
+  ties = c("discrete", "rounded"),
+  df = NULL,
+  ...
 ) {
-  UseMethod("survey_quantile", .svy)
-}
+  .svy <- cur_svy()
 
-#' @export
-survey_quantile.tbl_svy <- function(
-  x, quantiles, na.rm = FALSE, vartype = c("se", "ci"),
-  level = 0.95, q_method = "linear", f = 1,
-  interval_type = c("Wald", "score", "betaWald", "probability", "quantile"),
-  ties = c("discrete", "rounded"), df = NULL, .svy = current_svy(), ...
-) {
   if (!is.null(vartype)) {
     vartype <- if (missing(vartype)) "se" else match.arg(vartype, several.ok = TRUE)
   }
@@ -469,67 +401,22 @@ survey_quantile.tbl_svy <- function(
   out
 }
 
-#' @export
-survey_quantile.grouped_svy <- function(
-  x, quantiles, na.rm = FALSE, vartype = c("se", "ci"),
-  level = 0.95, q_method = "linear", f = 1,
-  interval_type = c("Wald", "score", "betaWald", "probability", "quantile"),
-  ties = c("discrete", "rounded"), df = NULL, .svy = current_svy(), ...
-) {
-  if (!is.null(vartype)) {
-    vartype <- if (missing(vartype)) "se" else match.arg(vartype, several.ok = TRUE)
-  }
-  if (missing(interval_type) & !inherits(.svy, "svyrep.design")) interval_type <- "Wald"
-  if (missing(interval_type) & inherits(.svy, "svyrep.design")) interval_type <- "probability"
-  interval_type <- match.arg(interval_type, several.ok = TRUE)
-  if (missing(ties)) ties <- "discrete"
-  ties <- match.arg(ties, several.ok = TRUE)
-
-  if (length(level) > 1) {
-    warning("Only the first confidence level will be used")
-    level <- level[1]
-  }
-
-  # Because of machine precision issues, 1 - 0.95 != 0.05...
-  # Here's a hacky way to force it, though it technically limits
-  # us to 7 digits of precision in alpha (seems like enough,
-  # we could go higher, but I worry about 32bit vs 64bit systems)
-  alpha = round(1 - level, 7)
-
-  grp_names <- group_vars(.svy)
-  if (missing(x)) stop("survey_quantile() can't be used with regards to the grouping variable.")
-  stop_for_factor(x)
-  .svy <- set_survey_vars(.svy, x)
-
-  # TODO: switch to improved svyquantile
-  if (utils::packageVersion("survey") >= "4.1") {
-    svyq_func <- get("oldsvyquantile", asNamespace("survey"))
-  } else {
-    svyq_func <- survey::svyquantile
-  }
-
-
-  stat <- survey::svyby(
-    formula = ~`__SRVYR_TEMP_VAR__`, survey::make.formula(grp_names), .svy,
-    svyq_func, quantiles = quantiles, na.rm = na.rm,
-    ci = TRUE, alpha = alpha, method = q_method,
-    f = f, interval.type = interval_type, ties = ties,
-    df = df, vartype = vartype
-  )
-
-  out <- get_var_est_quantile(stat, vartype, q = quantiles, grps = grp_names, level = level)
-
-  out
-}
-
 #' @export
 #' @rdname survey_quantile
 survey_median <- function(
-  x, na.rm = FALSE, vartype = c("se", "ci"),
-  level = 0.95, q_method = "linear", f = 1,
+  x,
+  na.rm = FALSE,
+  vartype = c("se", "ci"),
+  level = 0.95,
+  q_method = "linear",
+  f = 1,
   interval_type = c("Wald", "score", "betaWald", "probability", "quantile"),
-  ties = c("discrete", "rounded"), df = NULL, .svy = current_svy(), ...
+  ties = c("discrete", "rounded"),
+  df = NULL,
+  ...
 ) {
+  .svy <- cur_svy()
+
   if (!is.null(vartype)) {
     vartype <- if (missing(vartype)) "se" else match.arg(vartype, several.ok = TRUE)
   }
@@ -544,9 +431,9 @@ survey_median <- function(
     level <- level[1]
   }
 
-  out = survey_quantile(
+  out <- survey_quantile(
     x, quantiles = 0.5, na.rm = na.rm, vartype = vartype, level = level, q_method = q_method,
-    f = f, interval_type = interval_type, ties = ties, df = df, .svy = .svy
+    f = f, interval_type = interval_type, ties = ties, df = df
   )
   names(out) = sub("^_q50", "", names(out))
   out
@@ -569,8 +456,6 @@ survey_median <- function(
 #'           for t-distribution. The default (Inf) is equivalent to using normal
 #'           distribution and in case of population variance statistics there is little
 #'           reason to use any other values (see \emph{Details}).
-#' @param .svy A \code{tbl_svy} object. When called from inside a summarize function
-#'             the default automatically sets the survey to the current survey.
 #' @param ... Ignored
 #' @details
 #' Be aware that confidence intervals for population variance statistic are
@@ -616,25 +501,24 @@ survey_median <- function(
 #' @export
 
 survey_var <- function(
-  x, na.rm = FALSE, vartype = c("se", "ci", "var"), level = 0.95, df = NULL,
-  .svy = current_svy(), ...
+  x,
+  na.rm = FALSE,
+  vartype = c("se", "ci", "var"),
+  level = 0.95,
+  df = NULL,
+  ...
 ) {
-  UseMethod("survey_var", .svy)
-}
+  .svy <- cur_svy()
 
-#' @export
-survey_var.tbl_svy <- function(
-  x, na.rm = FALSE, vartype = c("se", "ci", "var"), level = 0.95, df = NULL,
-  .svy = current_svy(), ...
-) {
   if (!is.null(vartype)) {
     vartype <- if (missing(vartype)) "se" else match.arg(vartype, several.ok = TRUE)
   }
   if (missing(x)) stop("Variable should be provided as an argument to survey_var().")
   stop_for_factor(x)
+  if (length(x) < 2) stop("Population variance can't be computed because some groups contain less than 2 observations.")
   if (is.logical(x)) x <- as.integer(x)
 
-  if (is.null(df)) df <- survey::degf(.svy)
+  if (is.null(df)) df <- survey::degf(cur_svy_full())
 
   .svy <- set_survey_vars(.svy, x)
   stat <- survey::svyvar(~`__SRVYR_TEMP_VAR__`, .svy, na.rm = na.rm)
@@ -643,45 +527,15 @@ survey_var.tbl_svy <- function(
   out
 }
 
-#' @export
-survey_var.grouped_svy <- function(
-  x, na.rm = FALSE, vartype = c("se", "ci", "var"), level = 0.95, df = NULL,
-  .svy = current_svy(), ...
-) {
-  if (!is.null(vartype)) {
-    vartype <- if (missing(vartype)) "se" else match.arg(vartype, several.ok = TRUE)
-  }
-  if (missing(x)) stop("survey_var() can't be used with regards to the grouping variable.")
-  stop_for_factor(x)
-  if (is.logical(x)) x <- as.integer(x)
-  .svy <- set_survey_vars(.svy, x)
-  grps_formula <- survey::make.formula(group_vars(.svy))
-
-  if (any(dplyr::count(.svy$variables)$n < 2)) stop("Population variance can't be computed because some groups contain less than 2 observations.")
-
-  if (is.null(df)) df <- survey::degf(.svy)
-
-  stat <- survey::svyby(
-    ~`__SRVYR_TEMP_VAR__`, grps_formula, .svy, survey::svyvar,
-    na.rm = na.rm
-  )
-  out <- get_var_est(
-    stat, vartype, grps = group_vars(.svy), level = level, df = df, deff = FALSE
-  )
-  out
-}
-
 #' @export
 #' @rdname survey_var
 survey_sd <- function(
-  x, na.rm = FALSE, .svy = current_svy(), ...
+  x, na.rm = FALSE, ...
 ) {
-  out <- survey_var(
-    x, na.rm = na.rm, vartype = NULL, .svy = .svy
-  )
+  out <- survey_var(x, na.rm = na.rm, vartype = NULL)
   out <- mutate(
     out,
-    `__SRVYR_COEF__` = sqrt(.data$`__SRVYR_COEF__`)
+    coef = sqrt(.data$coef)
   )
   out
 }
@@ -689,7 +543,10 @@ survey_sd <- function(
 #' Calculate the an unweighted summary statistic from a survey
 #'
 #' Calculate unweighted summaries from a survey dataset, just as on
-#' a normal data.frame with \code{\link[dplyr]{summarise}}.
+#' a normal data.frame with \code{\link[dplyr]{summarise}}. Though it is
+#' possible to use regular functions directly, because the survey package
+#' doesn't always remove rows when filtering (instead setting the weight to 0),
+#' this can sometimes give bad results. See examples for more details.
 #'
 #' Uses tidy evaluation semantics and so if you want to use
 #' wrapper functions based on variable names, you must use
@@ -698,8 +555,6 @@ survey_sd <- function(
 #' 'programming' for more information.
 #'
 #' @param x A variable or expression
-#' @param .svy A \code{tbl_svy} object. When called from inside a summarize function
-#'   the default automatically sets the survey to the current survey.
 #' @param ... Ignored
 #' @examples
 #' library(survey)
@@ -718,24 +573,43 @@ survey_sd <- function(
 #'   summarise(api_diff_unw = unweighted(mean(api00 - api99)))
 #'
 #'
-#' # If you want to use a wrapper function, be sure to treat
-#' # non-standard evaluation correctly
-#' umean <- function(x) {
-#'   unweighted(mean({{x}}))
-#' }
-#'  dstrata %>%
-#'    group_by(stype) %>%
-#'    summarize(api_diff_unw = umean(api00 - api99))
+#' # Some survey designs, like ones with raked weights, are not removed
+#' # when filtered to preserve the structure. So if you don't use `unweighted()`
+#' # your results can be wrong.
+#' # Declare basic clustered design ----
+#' cluster_design <- as_survey_design(
+#'   .data = apiclus1,
+#'   id = dnum,
+#'   weights = pw,
+#'   fpc = fpc
+#' )
 #'
+#' # Add raking weights for school type ----
+#' pop.types <- data.frame(stype=c("E","H","M"), Freq=c(4421,755,1018))
+#' pop.schwide <- data.frame(sch.wide=c("No","Yes"), Freq=c(1072,5122))
+#'
+#' raked_design <- rake(
+#'   cluster_design,
+#'   sample.margins = list(~stype,~sch.wide),
+#'   population.margins = list(pop.types, pop.schwide)
+#' )
+#'
+#' raked_design %>%
+#' filter(cname != "Alameda") %>%
+#'   group_by(cname) %>%
+#'   summarize(
+#'     direct_unw_mean = mean(api99),
+#'     wrapped_unw_mean = unweighted(mean(api99))
+#'   ) %>%
+#'   filter(cname == "Alameda")
+#'
+#' # Notice how the results are different when using `unweighted()`
 #'
 #' @export
-unweighted <- function(x, .svy = current_svy(), ...) {
+unweighted <- function(x, ...) {
+  .svy <- cur_svy()
+
   dots <- rlang::enquo(x)
-  # unweighted needs to be evaluated in grandparent environment (in
-  # the caller of summarise) because we don't want the same kind of
-  # vector retrieval from the survey's variables as we do for other
-  # survey statistics
-  dots <- rlang::quo_set_env(dots, rlang::env_parent(n = 2))
 
   if (is.calibrated(.svy) | is.pps(.svy)) {
     excluded_rows <- is.infinite(.svy[['prob']])
@@ -747,77 +621,3 @@ unweighted <- function(x, .svy = current_svy(), ...) {
   names(out)[length(names(out))] <- ""
   out
 }
-
-survey_stat_factor <- function(.svy, func, na.rm, vartype, level, deff, df) {
-  grps_names <- group_vars(.svy)
-  .svy <- set_survey_vars(.svy, NULL)
-  peel_name <- grps_names[length(grps_names)]
-  grps_names <- setdiff(grps_names, peel_name)
-
-  if (is.numeric(.svy$variables[[peel_name]])) {
-    warning("Coercing ", peel_name, " to character.", call. = FALSE)
-    peel_var_coerced_to_char <- TRUE
-    peel_var_orig_type <- typeof(.svy$variables[[peel_name]])
-    .svy$variables[[peel_name]] <- format(.svy$variables[[peel_name]], nsmall = 20, digits = 22)
-  } else {
-    peel_var_coerced_to_char <- FALSE
-  }
-
-  # If any groups have NAs the survey package will drop them, so convert to
-  # explicit levels that will get dropped
-  for (grp_var_name in c(peel_name, grps_names)) {
-    if (any(is.na(.svy$variables[[grp_var_name]]))) {
-      if (is.factor(.svy$variables[[grp_var_name]])) {
-        levels(.svy$variables[[grp_var_name]]) <- c(levels(.svy$variables[[grp_var_name]]), "__SRVYR_NA_LEVEL__")
-      }
-      .svy$variables[[grp_var_name]][is.na(.svy$variables[[grp_var_name]])] <- "__SRVYR_NA_LEVEL__"
-    }
-  }
-
-  if (length(level) > 1) {
-    warning("Only the first confidence level will be used")
-    level <- level[1]
-  }
-
-  peel_is_factor <- is.factor(.svy[["variables"]][[peel_name]])
-  if (peel_is_factor) {
-    peel_levels <- levels(.svy[["variables"]][[peel_name]])
-    peel_is_ordered <- is.ordered(.svy[["variables"]][[peel_name]])
-  } else {
-    peel_levels <- sort(unique(.svy[["variables"]][[peel_name]]))
-    peel_is_ordered <- FALSE
-  }
-  if (length(grps_names) > 0) {
-    stat <- survey::svyby(survey::make.formula(peel_name),
-                          survey::make.formula(grps_names),
-                          .svy, func, na.rm = na.rm, se = TRUE, deff = deff)
-
-    var_names <- attr(stat, "svyby")[["variables"]]
-    var_names <- unlist(lapply(var_names, function(x) substring(x, nchar(peel_name) + 1)))
-
-
-    out <- get_var_est_factor(
-      stat, vartype, grps = grps_names, peel = peel_name,
-      peel_is_factor = peel_is_factor, peel_levels = peel_levels, peel_is_ordered = peel_is_ordered,
-      level = level, df = df, deff = deff
-    )
-  } else {
-    stat <- func(survey::make.formula(peel_name), .svy, na.rm = na.rm, deff = deff)
-
-    out <- get_var_est_factor(
-      stat, vartype, grps = "", peel = peel_name, peel_levels = peel_levels, peel_is_ordered = peel_is_ordered,
-       peel_is_factor = peel_is_factor, df = df, deff = deff
-    )
-  }
-
-  # set back to NA the NAs that were forced to be explicit
-  for (grp_var_name in c(peel_name, grps_names)) {
-    out[[grp_var_name]][out[[grp_var_name]] == "__SRVYR_NA_LEVEL__"] <- NA
-  }
-
-  if (peel_var_coerced_to_char) {
-    out[[peel_name]] <- methods::as(out[[peel_name]], peel_var_orig_type)
-  }
-
-  out
-}
